
.. blogpost::
    :title: Install Theano on Linux
    :keywords: install, theano, tdm-g++
    :date: 2015-09-12
    :categories: install, module, windows

    The module `theano <http://deeplearning.net/software/theano/>`_
    involves some C++ and requires a compiler.
    For Windows, I recommend to read section
    `Installation of Theano on Windows <http://deeplearning.net/software/theano/install_windows.html?highlight=tdm>`_.
    It requires `tdm-gcc <http://tdm-gcc.tdragon.net/>`_.
